@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from xlsx_lib.domain.generic_replacements.replacement_part import ReplacementPart
 
@@ -7,10 +7,10 @@ from xlsx_lib.domain.generic_replacements.replacement_part import ReplacementPar
 class Replacement:
     name: str
     reference: str
-    observations: str
+    observations: Optional[str]
     parts: List[ReplacementPart]
 
-    def __init__(self, name: str, reference: str, observations: str):
+    def __init__(self, name: str, reference: str, observations: Optional[str]):
         self.name = name
         self.reference = reference
         self.observations = observations
